@@ -27,13 +27,13 @@ class PagesAdmin(admin.ModelAdmin):
 
 
 class MenuAdmin(FeinCMSModelAdmin):
-    list_display = ('name', 'url', 'menu_id', 'published')
+    list_display = ('name', 'url', 'published')
 
     fieldsets = [
         (None, {'fields': ['name', 'url', 'parent']}),
         (_('Menu settings'), {
             'classes': ('collapse',),
-            'fields': ['menu_id', 'published']
+            'fields': ['published', ]
         }),
     ]
 
